@@ -95,6 +95,7 @@ journal (GtkWidget *w, gpointer user_data)
       GtkCTreeNode *node = GTK_CTREE_NODE (GTK_CLIST (ct)->selection->data);
       struct task *t;
       t = gtk_ctree_node_get_row_data (ct, node);
+     
       /* here we go... */
       journal_add_header(t->description);
       scan_journal(g_slist_find(root,t));
@@ -102,6 +103,10 @@ journal (GtkWidget *w, gpointer user_data)
       journal_to_file(JOURNAL_FILE);
       journal_show(JOURNAL_FILE);
     }
+  else
+    {
+     gpe_error_box(_("No data selected for journal!"));
+    }
 }
 
 
@@ -232,14 +237,12 @@ confirm_dialog (gchar **text, gchar *action, gchar *action2)
 
   if (destroyed)
     return FALSE;
-#if 0
   {
     GtkTextBuffer *buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (entry));
     GtkTextIter start, end;
     gtk_text_buffer_get_bounds (buf, &start, &end);
     *text = gtk_text_buffer_get_text (buf, &start, &end, FALSE);
   }
-#endif
 
   destroyed = TRUE;
   gtk_widget_destroy (w);
@@ -310,6 +313,9 @@ ui_new_task (GtkWidget *w, gpointer p)
   gchar *text[2];
   struct task *pt = NULL;
 
+  /* removing this avoids creating strange subtasks which don't
+     show in the reports + avoids confusing the user creating a new 
+     node or leaf depending on the selection
   if (GTK_CLIST (ctree)->selection)
     {
       gchar *text;
@@ -320,9 +326,9 @@ ui_new_task (GtkWidget *w, gpointer p)
 			       NULL, NULL, NULL, NULL, &leaf, NULL);
       if (leaf)
 	gtk_ctree_set_node_info (ctree, parent, text, 0,
-				 NULL, NULL, NULL, NULL, FALSE, TRUE);
+				 NULL, NULL, NULL, NULL, TRUE, TRUE);
     }
-  
+  */
   text[0] = smallbox (_("New task"), _("Name"), "");
   text[1] = "";
   if (text[0])
